@@ -1,11 +1,7 @@
 package Role::Tiny::With;
 
 use strict;
-use warnings;
-
-our $VERSION = '1.999_001';
-$VERSION = eval $VERSION;
-
+use warnings FATAL => 'all';
 use Role::Tiny ();
 
 use Exporter 'import';
@@ -13,7 +9,7 @@ our @EXPORT = qw( with );
 
 sub with {
     my $target = caller;
-    Role::Tiny->apply_roles_to_package($target, @_)
+    Role::Tiny->apply_role_to_package($target, @_)
 }
 
 1;
